@@ -239,7 +239,7 @@ cfgfile_get_wm_info_data_file_path (int *i_err)
 char *
 cfgfile_get_app_wallpapers_path (void)
 {
-    char *s_path = NULL; /* Config file path */
+    char *s_path = NULL; /* Result directory path */
 
     s_path = dir_get_home_data ();
     str_append (&s_path, PTH_SEP PTH_APP_SHORT PTH_SEP PTH_WALLP_DIR);
@@ -253,7 +253,7 @@ cfgfile_get_app_wallpapers_path (void)
 char *
 cfgfile_get_app_cache_path (void)
 {
-    char *s_path = NULL; /* Config file path */
+    char *s_path = NULL; /* Result directory path */
 
     s_path = dir_get_cache ();
     str_append (&s_path, PTH_SEP PTH_APP_SHORT);
@@ -267,7 +267,7 @@ cfgfile_get_app_cache_path (void)
 char *
 cfgfile_get_app_thumbnails_path (void)
 {
-    char *s_path = NULL; /* Config file path */
+    char *s_path = NULL; /* Result directory path */
 
     s_path = dir_get_cache ();
     str_append (&s_path, PTH_SEP PTH_APP_SHORT PTH_SEP PTH_THUMB_DIR);
@@ -281,7 +281,7 @@ cfgfile_get_app_thumbnails_path (void)
 char *
 cfgfile_get_image_info_path (void)
 {
-    char *s_path = NULL; /* Config file path */
+    char *s_path = NULL; /* Result directory path */
 
     s_path = dir_get_cache ();
     str_append (&s_path, PTH_SEP PTH_APP_SHORT PTH_SEP PTH_IINFO_DIR);
@@ -289,6 +289,20 @@ cfgfile_get_image_info_path (void)
     return s_path;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get directory with cached queries.
+ */
+char *
+cfgfile_get_query_path (void)
+{
+    char *s_path = NULL; /* Result directory path */
+
+    s_path = dir_get_cache ();
+    str_append (&s_path, PTH_SEP PTH_APP_SHORT PTH_SEP PTH_QUERY_DIR);
+
+    return s_path;
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Check if wchangerd daemon desktop file exists in user's autostart
  *         directory.
@@ -327,7 +341,7 @@ cfgfile_autostart_create (void)
 
     str_append (&s_path, PTH_SEP PTH_ASTART_FILE_S);
 
-    s_buff = read_file_data (s_path, &i_err);
+    s_buff = read_file_data (s_path, &i_err, NULL);
     if (s_buff != NULL && i_err == ERR_OK) {
         if ((i_err = file_check_permissions (s_as_path)) == ERR_FILE_EX) {
             if ((i_err = file_create_with_subdirs (s_as_path)) == ERR_OK) {
